// package.json
var package_default = {
  name: "create-wagmi",
  description: "Create wagmi apps with one command",
  version: "0.0.0-20221123060304",
  type: "module",
  license: "MIT",
  bin: {
    "create-wagmi": "dist/index.js"
  },
  scripts: {
    build: "tsup",
    "changeset:release": "pnpm build && changeset publish",
    "changeset:version": "changeset version && pnpm install --lockfile-only",
    dev: "tsup --watch",
    lint: "eslint . --cache",
    "lint:fix": "pnpm lint --fix",
    "lint:format": "prettier --write",
    prepare: "npx simple-git-hooks",
    typecheck: "tsc --noEmit"
  },
  dependencies: {
    cac: "^6.7.14",
    cpy: "^9.0.1",
    "cross-spawn": "^7.0.3",
    "detect-package-manager": "^2.0.1",
    execa: "^6.1.0",
    "fs-extra": "^10.1.0",
    ora: "^6.1.2",
    picocolors: "^1.0.0",
    prompts: "^2.4.2",
    "update-check": "^1.5.4",
    "validate-npm-package-name": "^4.0.0"
  },
  devDependencies: {
    "@changesets/changelog-github": "^0.4.4",
    "@changesets/cli": "^2.22.0",
    "@types/cross-spawn": "^6.0.2",
    "@types/eslint": "^8.4.6",
    "@types/fs-extra": "^9.0.13",
    "@types/node": "^18.11.7",
    "@types/prompts": "^2.4.1",
    "@types/validate-npm-package-name": "^4.0.0",
    "@typescript-eslint/eslint-plugin": "^5.37.0",
    "@typescript-eslint/parser": "^5.37.0",
    eslint: "8.17.0",
    "eslint-config-prettier": "^8.5.0",
    "eslint-import-resolver-typescript": "^2.7.1",
    "eslint-plugin-eslint-comments": "^3.2.0",
    "eslint-plugin-import": "^2.26.0",
    "eslint-plugin-prettier": "^4.2.1",
    "eslint-plugin-react-hooks": "^4.6.0",
    "lint-staged": "^13.0.3",
    prettier: "^2.7.1",
    "simple-git-hooks": "^2.8.1",
    tsup: "^6.2.3",
    typescript: "^4.8.4"
  },
  "simple-git-hooks": {
    "pre-commit": "pnpm lint-staged"
  },
  "lint-staged": {
    "*.{js,ts,tsx}": [
      "pnpm lint:fix"
    ],
    "*.{json,md,yml}": [
      "pnpm lint:format"
    ]
  },
  files: [
    "dist",
    "templates"
  ],
  repository: {
    type: "git",
    url: "https://github.com/wagmi-dev/wagmi.git"
  }
};

// src/utils/createTemplate.ts
function createTemplate(template) {
  return template;
}

// src/utils/getPackageManager.ts
import { detect } from "detect-package-manager";
var getPackageManager = ({ options }) => {
  if (options) {
    if (options.npm)
      return "npm";
    if (options.pnpm)
      return "pnpm";
    if (options.yarn)
      return "yarn";
  }
  const userAgent = process.env.npm_config_user_agent;
  if (userAgent) {
    if (userAgent.includes("pnpm"))
      return "pnpm";
    if (userAgent.includes("npm"))
      return "npm";
    if (userAgent.includes("yarn"))
      return "yarn";
  }
  return detect();
};

// src/generated/templateImports.ts
var templateImports_default = [
  () => import("./_meta-U54OZNBC.js"),
  () => import("./_meta-GYWFGW6B.js"),
  () => import("./_meta-VALO6KLW.js"),
  () => import("./_meta-VS2ALTFY.js"),
  () => import("./_meta-KPKCVNDW.js"),
  () => import("./_meta-LOMTZN7S.js")
];

// src/meta.ts
var templates = [
  "next",
  "next-with-connectkit",
  "next-with-rainbowkit",
  "next-with-web3modal",
  "create-react-app",
  "vite-react"
];

// src/utils/getTemplatesMeta.ts
var getTemplatesMeta = async () => {
  let templates2 = await Promise.all(
    templateImports_default.map(
      async (templateImport) => (await templateImport()).default
    )
  );
  let orderedTemplates = [];
  templates.forEach((templateName) => {
    const template = templates2.find(
      (template2) => template2.name === templateName
    );
    if (!template)
      return;
    orderedTemplates = [...orderedTemplates, template];
    templates2 = templates2.filter((template2) => template2.name !== templateName);
  });
  return [...orderedTemplates, ...templates2];
};

// src/utils/notifyUpdate.ts
import pico from "picocolors";
import checkForUpdate from "update-check";
var log = console.log;
async function notifyUpdate({ options }) {
  try {
    const res = await checkForUpdate(package_default);
    if (res == null ? void 0 : res.latest) {
      const packageManager = await getPackageManager({ options });
      const updateMessage = packageManager === "pnpm" ? "pnpm add -g create-wagmi" : packageManager === "yarn" ? "yarn global add create-wagmi" : "npm i -g create-wagmi";
      log(
        pico.bold(
          pico.yellow("A new version of `create-wagmi` is available!") + "\nYou can update by running: " + pico.cyan(updateMessage) + "\n"
        )
      );
    }
    process.exit();
  } catch {
  }
}

// src/utils/validate.ts
import fs from "fs-extra";
import pico2 from "picocolors";
import validatePackageName from "validate-npm-package-name";
import path from "path";
async function validateProjectName({
  projectName,
  projectPath
}) {
  const nameValidation = validatePackageName(projectName);
  if (!nameValidation.validForNewPackages) {
    const problems = [
      ...nameValidation.errors ?? [],
      ...nameValidation.warnings ?? []
    ];
    return {
      valid: false,
      message: `\u{1F648} "${projectName}" is not a valid project name.`,
      problems: problems.map((problem) => `\u{1F449} ${problem}`).join("\n")
    };
  }
  const targetPath = path.join(process.cwd(), projectPath);
  if (await fs.pathExists(targetPath))
    return {
      valid: false,
      message: `\u{1F648} the directory "${projectPath}" already exists.`,
      problems: "\u{1F449} choose another name or delete the directory."
    };
  return {
    valid: true
  };
}
async function validateTemplateName({
  isNameRequired = true,
  templateName,
  templatesPath,
  templates: templates2
}) {
  if (isNameRequired && !templateName)
    return {
      valid: false,
      message: `\u{1F648} no template provided.`,
      problems: "\u{1F449} select a template or provide one using --template."
    };
  if (templateName && !await fs.pathExists(path.join(templatesPath, templateName)))
    return {
      valid: false,
      message: `\u{1F648} the template "${templateName}" does not exist.`,
      problems: `Choose a valid name. Available: ${templates2.map(({ name }) => name).join(", ")}`
    };
  return { valid: true };
}
var ValidationError = class extends Error {
  name = "ValidationError";
  constructor(validation) {
    super([pico2.red(validation.message), validation.problems].join("\n"));
  }
};

// src/utils/warnings.ts
import pico3 from "picocolors";
var log2 = console.log;
function rpcProviderWarning({
  readMoreUrl = "https://wagmi.sh/docs/getting-started#configure-chains"
} = {}) {
  log2(
    `${pico3.yellow(
      "Important note:"
    )} It is HIGHLY recommended that you add an ${pico3.bold(
      pico3.underline(`alchemyProvider`)
    )}, ${pico3.bold(pico3.underline("infuraProvider"))}, or alike to ${pico3.blue(
      "src/wagmi.ts"
    )} before deploying your project to production to prevent being rate-limited.`
  );
  log2();
  log2(`Read more: ${pico3.blue(pico3.underline(readMoreUrl))}`);
}

export {
  package_default,
  createTemplate,
  getPackageManager,
  getTemplatesMeta,
  notifyUpdate,
  validateProjectName,
  validateTemplateName,
  ValidationError,
  rpcProviderWarning
};
